@@ -10,8 +10,8 @@ def formats():
     }
 
 
-_list_keys = ["id", "name", "username", "autoCreated", "shared", "public"]
-_item_keys = ["id", "name", "username", "autoCreated", "shared", "public", "filterExpression"]
+_list_keys = ["id", "name", "username", "autoCreated", "shared", "public", "favorite"]
+_item_keys = ["id", "name", "username", "autoCreated", "shared", "public", "favorite", "filterExpression"]
 
 
 def print_dashboard(dashboard):
