@@ -125,6 +125,25 @@ def query_metadata(cnf, input_image, metadata_type):
         sys.exit(1)
 
 
+@image.command(name='evaluation', short_help="Check latest policy evaluation for an image")
+@click.option("--detail", is_flag=True, help="Show detailed policy evaluation report")
+@click.option("--policy", help="Specify which POLICY to use for evaluate (defaults currently active policy)")
+@click.argument('input_image', nargs=1)
+@click.pass_obj
+def check(cnf, input_image, detail, policy):
+    """
+    INPUT_IMAGE: Input image can be in the following formats: Image Digest, ImageID or registry/repo:tag
+    """
+    try:
+        res = use_case.get_image_scanning_results(cnf.sdscanning, input_image, policy=policy)
+        cnf.formatter.format((res, detail), "scanningEvaluationImage")
+    except Exception as ex:
+        print(f"Error: {str(ex)}")
+        if policy:
+            print("Check if the image has been assigned to the provided policy")
+        sys.exit(1)
+
+
 @image.command(name='vuln', short_help="Get image vulnerabilities")
 @click.argument('input_image', nargs=1)
 @click.argument('vuln_type', nargs=1, default='all')
@@ -151,30 +170,6 @@ def query_vuln(cnf, input_image, vuln_type, vendor_only):
         sys.exit(1)
 
 
-@image.command(name='evaluation', short_help="Check latest policy evaluation for an image")
-@click.option("--show-history", is_flag=True, help="Show all previous policy evaluations")
-@click.option("--detail", is_flag=True, help="Show detailed policy evaluation report")
-@click.option("--tag", help="Specify which TAG is evaluated for a given image ID or Image Digest")
-@click.option("--policy", help="Specify which POLICY to use for evaluate (defaults currently active policy)")
-@click.argument('input_image', nargs=1)
-@click.pass_obj
-def check(cnf, input_image, show_history, detail, tag, policy):
-    """
-    INPUT_IMAGE: Input image can be in the following formats: Image Digest, ImageID or registry/repo:tag
-    """
-    try:
-        res = use_case.check_image_evaluation(
-            cnf.sdscanning, input_image,
-            show_history=show_history,
-            detail=detail,
-            tag=tag,
-            policy=policy)
-        cnf.formatter.format((res, detail), "scanningEvaluationImage")
-    except Exception as ex:
-        print(f"Error: {str(ex)}")
-        sys.exit(1)
-
-
 @image.command(name='pdf-report', short_help="Get the scan report for an image in pdf")
 @click.option("--tag", help="Specify which TAG is evaluated for a given image ID or Image Digest")
 @click.option("--date", help="Specify a date for the report")
