@@ -81,14 +81,8 @@ def query_image_vuln(scanning: SdScanningClient, input_image, vuln_type="all", v
     return res
 
 
-def check_image_evaluation(scanning: SdScanningClient, input_image, show_history, detail, tag, policy):
-    ok, res = scanning.check_image_evaluation(
-        input_image,
-        show_history=show_history,
-        detail=detail,
-        tag=tag,
-        policy=policy)
-
+def get_image_scanning_results(scanning: SdScanningClient, input_image, policy):
+    ok, res = scanning.get_image_scanning_results(input_image, policy)
     if not ok:
         raise Exception(res)
     return res
